==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QSGNinePatchNode.java <==
package io.qt.quick;


/**
 * <p>Java wrapper for Qt class QSGNinePatchNode</p>
 */
public abstract class QSGNinePatchNode extends io.qt.quick.QSGGeometryNode
{
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGNinePatchNode {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void setBounds(io.qt.core.QRectF bounds){
            setBounds_native_cref_QRectF(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(bounds));
        }
        @io.qt.QtUninvokable
        private native void setBounds_native_cref_QRectF(long __this__nativeId, long bounds);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setDevicePixelRatio(double ratio){
            setDevicePixelRatio_native_qtjambireal(QtJambi_LibraryUtilities.internal.nativeId(this), ratio);
        }
        @io.qt.QtUninvokable
        private native void setDevicePixelRatio_native_qtjambireal(long __this__nativeId, double ratio);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setPadding(double left, double top, double right, double bottom){
            setPadding_native_qtjambireal_qtjambireal_qtjambireal_qtjambireal(QtJambi_LibraryUtilities.internal.nativeId(this), left, top, right, bottom);
        }
        @io.qt.QtUninvokable
        private native void setPadding_native_qtjambireal_qtjambireal_qtjambireal_qtjambireal(long __this__nativeId, double left, double top, double right, double bottom);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setTexture(io.qt.quick.QSGTexture texture){
            setTexture_native_QSGTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(texture));
        }
        @io.qt.QtUninvokable
        private native void setTexture_native_QSGTexture_ptr(long __this__nativeId, long texture);
        
        
        @Override
        @io.qt.QtUninvokable
        public void update(){
            update_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void update_native(long __this__nativeId);
        
    }
    
    
    public QSGNinePatchNode(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGNinePatchNode instance);
    
    @io.qt.QtUninvokable
    public abstract void setBounds(io.qt.core.QRectF bounds);
    
    @io.qt.QtUninvokable
    private native void setBounds_native_cref_QRectF(long __this__nativeId, long bounds);
    
    @io.qt.QtUninvokable
    public abstract void setDevicePixelRatio(double ratio);
    
    @io.qt.QtUninvokable
    private native void setDevicePixelRatio_native_qtjambireal(long __this__nativeId, double ratio);
    
    @io.qt.QtUninvokable
    public abstract void setPadding(double left, double top, double right, double bottom);
    
    @io.qt.QtUninvokable
    private native void setPadding_native_qtjambireal_qtjambireal_qtjambireal_qtjambireal(long __this__nativeId, double left, double top, double right, double bottom);
    
    @io.qt.QtUninvokable
    public abstract void setTexture(io.qt.quick.QSGTexture texture);
    
    @io.qt.QtUninvokable
    private native void setTexture_native_QSGTexture_ptr(long __this__nativeId, long texture);
    
    @io.qt.QtUninvokable
    public abstract void update();
    
    @io.qt.QtUninvokable
    private native void update_native(long __this__nativeId);
    
    public static void rebuildGeometry(io.qt.quick.QSGTexture texture, io.qt.quick.QSGGeometry geometry, io.qt.gui.QVector4D padding, io.qt.core.QRectF bounds, double dpr){
        rebuildGeometry_native_QSGTexture_ptr_QSGGeometry_ptr_cref_QVector4D_cref_QRectF_qtjambireal(QtJambi_LibraryUtilities.internal.checkedNativeId(texture), QtJambi_LibraryUtilities.internal.checkedNativeId(geometry), QtJambi_LibraryUtilities.internal.checkedNativeId(padding), QtJambi_LibraryUtilities.internal.checkedNativeId(bounds), dpr);
    }
    
    private native static void rebuildGeometry_native_QSGTexture_ptr_QSGGeometry_ptr_cref_QVector4D_cref_QRectF_qtjambireal(long texture, long geometry, long padding, long bounds, double dpr);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGNinePatchNode(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QSGNinePatchNode.java <==
package io.qt.quick;


/**
 * <p>Java wrapper for Qt class QSGNinePatchNode</p>
 */
public abstract class QSGNinePatchNode extends io.qt.quick.QSGGeometryNode
{
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QSGNinePatchNode {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void setBounds(io.qt.core.QRectF bounds){
            setBounds_native_cref_QRectF(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(bounds));
        }
        @io.qt.QtUninvokable
        private native void setBounds_native_cref_QRectF(long __this__nativeId, long bounds);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setDevicePixelRatio(double ratio){
            setDevicePixelRatio_native_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), ratio);
        }
        @io.qt.QtUninvokable
        private native void setDevicePixelRatio_native_qreal(long __this__nativeId, double ratio);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setPadding(double left, double top, double right, double bottom){
            setPadding_native_qreal_qreal_qreal_qreal(QtJambi_LibraryUtilities.internal.nativeId(this), left, top, right, bottom);
        }
        @io.qt.QtUninvokable
        private native void setPadding_native_qreal_qreal_qreal_qreal(long __this__nativeId, double left, double top, double right, double bottom);
        
        
        @Override
        @io.qt.QtUninvokable
        public void setTexture(io.qt.quick.QSGTexture texture){
            setTexture_native_QSGTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(texture));
        }
        @io.qt.QtUninvokable
        private native void setTexture_native_QSGTexture_ptr(long __this__nativeId, long texture);
        
        
        @Override
        @io.qt.QtUninvokable
        public void update(){
            update_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void update_native(long __this__nativeId);
        
    }
    
    
    public QSGNinePatchNode(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QSGNinePatchNode instance);
    
    @io.qt.QtUninvokable
    public abstract void setBounds(io.qt.core.QRectF bounds);
    
    @io.qt.QtUninvokable
    private native void setBounds_native_cref_QRectF(long __this__nativeId, long bounds);
    
    @io.qt.QtUninvokable
    public abstract void setDevicePixelRatio(double ratio);
    
    @io.qt.QtUninvokable
    private native void setDevicePixelRatio_native_qreal(long __this__nativeId, double ratio);
    
    @io.qt.QtUninvokable
    public abstract void setPadding(double left, double top, double right, double bottom);
    
    @io.qt.QtUninvokable
    private native void setPadding_native_qreal_qreal_qreal_qreal(long __this__nativeId, double left, double top, double right, double bottom);
    
    @io.qt.QtUninvokable
    public abstract void setTexture(io.qt.quick.QSGTexture texture);
    
    @io.qt.QtUninvokable
    private native void setTexture_native_QSGTexture_ptr(long __this__nativeId, long texture);
    
    @io.qt.QtUninvokable
    public abstract void update();
    
    @io.qt.QtUninvokable
    private native void update_native(long __this__nativeId);
    
    public static void rebuildGeometry(io.qt.quick.QSGTexture texture, io.qt.quick.QSGGeometry geometry, io.qt.gui.QVector4D padding, io.qt.core.QRectF bounds, double dpr){
        rebuildGeometry_native_QSGTexture_ptr_QSGGeometry_ptr_cref_QVector4D_cref_QRectF_qreal(QtJambi_LibraryUtilities.internal.checkedNativeId(texture), QtJambi_LibraryUtilities.internal.checkedNativeId(geometry), QtJambi_LibraryUtilities.internal.checkedNativeId(padding), QtJambi_LibraryUtilities.internal.checkedNativeId(bounds), dpr);
    }
    
    private native static void rebuildGeometry_native_QSGTexture_ptr_QSGGeometry_ptr_cref_QVector4D_cref_QRectF_qreal(long texture, long geometry, long padding, long bounds, double dpr);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSGNinePatchNode(QPrivateConstructor p) { super(p); } 
    
}
